@@ -75,10 +75,10 @@ def test_ChangesetUpdate(auth_api, add_response):
     result = auth_api.ChangesetUpdate({"test": "foobar"})
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.1.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="test" v="foobar"/>\n'
-        b'    <tag k="created_by" v="osmapi/4.0.0"/>\n'
+        b'    <tag k="created_by" v="osmapi/4.1.0"/>\n'
         b"  </changeset>\n"
         b"</osm>\n"
     )
@@ -98,7 +98,7 @@ def test_ChangesetUpdate_with_created_by(auth_api, add_response):
     result = auth_api.ChangesetUpdate({"test": "foobar", "created_by": "MyTestOSMApp"})
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.1.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="test" v="foobar"/>\n'
         b'    <tag k="created_by" v="MyTestOSMApp"/>\n'
@@ -122,10 +122,10 @@ def test_ChangesetCreate(auth_api, add_response):
 
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.1.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="foobar" v="A new test changeset"/>\n'
-        b'    <tag k="created_by" v="osmapi/4.0.0"/>\n'
+        b'    <tag k="created_by" v="osmapi/4.1.0"/>\n'
         b"  </changeset>\n"
         b"</osm>\n"
     )
@@ -145,7 +145,7 @@ def test_ChangesetCreate_with_created_by(auth_api, add_response):
 
     changeset_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osm version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osm version="0.6" generator="osmapi/4.1.0">\n'
         b'  <changeset visible="true">\n'
         b'    <tag k="foobar" v="A new test changeset"/>\n'
         b'    <tag k="created_by" v="CoolTestApp"/>\n'
@@ -218,7 +218,7 @@ def test_ChangesetUpload_create_node(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.1.0">\n'
         b"<create>\n"
         b'  <node lat="47.123" lon="8.555" visible="true" '
         b'changeset="4444">\n'
@@ -283,7 +283,7 @@ def test_ChangesetUpload_modify_way(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.1.0">\n'
         b"<modify>\n"
         b'  <way id="4294967296" version="2" visible="true" '
         b'changeset="4444">\n'
@@ -354,7 +354,7 @@ def test_ChangesetUpload_delete_relation(auth_api, add_response):
 
     upload_xml = xmltosorteddict(
         b'<?xml version="1.0" encoding="UTF-8"?>\n'
-        b'<osmChange version="0.6" generator="osmapi/4.0.0">\n'
+        b'<osmChange version="0.6" generator="osmapi/4.1.0">\n'
         b"<delete>\n"
         b'  <relation id="676" version="2" visible="true" '
         b'changeset="4444">\n'
@@ -490,8 +490,8 @@ def test_ChangesetDownloadContainingUnicode(api, add_response):
                 "tag": {
                     "highway": "service",
                     # UTF-8 encoded 'LATIN SMALL LETTER O WITH STROKE'
-                    # Aka. 0xf8 in latin-1/ISO 8859-1
-                    "name": b"S\xc3\xb8nderskovvej".decode("utf-8"),
+                    # Aka. 0xf8 in latin-1/ISO 8859-1             Emoji: 😀
+                    "name": b"S\xc3\xb8nderskovvej".decode("utf-8") + " \U0001f600",
                     "service": "driveway",
                 },
                 "timestamp": datetime.datetime(2016, 2, 23, 16, 55, 35),
